@@ -143,6 +143,7 @@ class SoCo(_SocoSingletonBase):
         play_uri
         pause
         stop
+        end_direct_control_session
         seek
         next
         previous
@@ -155,6 +156,7 @@ class SoCo(_SocoSingletonBase):
         ramp_to_volume
         set_relative_volume
         get_current_track_info
+        get_current_media_info
         get_speaker_info
         get_current_transport_info
 
@@ -235,6 +237,7 @@ class SoCo(_SocoSingletonBase):
         create_stereo_pair
         separate_stereo_pair
         get_battery_info
+        boot_seqnum
 
     .. warning::
 
@@ -291,6 +294,7 @@ class SoCo(_SocoSingletonBase):
 
         # Some private attributes
         self._all_zones = set()
+        self._boot_seqnum = None
         self._groups = set()
         self._is_bridge = None
         self._is_coordinator = False
@@ -310,6 +314,12 @@ class SoCo(_SocoSingletonBase):
     def __repr__(self):
         return '{}("{}")'.format(self.__class__.__name__, self.ip_address)
 
+    @property
+    def boot_seqnum(self):
+        """int: The boot sequence number."""
+        self._parse_zone_group_state()
+        return int(self._boot_seqnum)
+
     @property
     def player_name(self):
         """str: The speaker's name."""
@@ -716,6 +726,11 @@ class SoCo(_SocoSingletonBase):
         """Stop the currently playing track."""
         self.avTransport.Stop([("InstanceID", 0), ("Speed", 1)])
 
+    @only_on_master
+    def end_direct_control_session(self):
+        """Ends all third-party controlled streaming sessions."""
+        self.avTransport.EndDirectControlSession([("InstanceID", 0)])
+
     @only_on_master
     def seek(self, position=None, track=None):
         """Seek to a given position.
@@ -1179,6 +1194,7 @@ class SoCo(_SocoSingletonBase):
             # the zone is as yet unseen.
             zone._uid = member_attribs["UUID"]
             zone._player_name = member_attribs["ZoneName"]
+            zone._boot_seqnum = member_attribs["BootSeq"]
             # add the zone to the set of all members, and to the set
             # of visible members if appropriate
             is_visible = member_attribs.get("Invisible") != "1"
@@ -1203,8 +1219,11 @@ class SoCo(_SocoSingletonBase):
         # and the set of all members
         self._all_zones.clear()
         self._visible_zones.clear()
+        # Compatibility fallback for pre-10.1 firmwares
+        # where a "ZoneGroups" element is not used
+        tree = tree.find("ZoneGroups") or tree
         # Loop over each ZoneGroup Element
-        for group_element in tree.find("ZoneGroups").findall("ZoneGroup"):
+        for group_element in tree.findall("ZoneGroup"):
             coordinator_uid = group_element.attrib["Coordinator"]
             group_uid = group_element.attrib["ID"]
             group_coordinator = None
@@ -1615,6 +1634,31 @@ class SoCo(_SocoSingletonBase):
 
         return track
 
+    def get_current_media_info(self):
+        """Get information about the currently playing media.
+
+        Returns:
+            dict: A dictionary containing information about the currently
+            playing media: uri, channel.
+
+        If we're unable to return data for a field, we'll return an empty
+        string.
+        """
+        response = self.avTransport.GetMediaInfo([("InstanceID", 0)])
+        media = {"uri": "", "channel": ""}
+
+        media["uri"] = response["CurrentURI"]
+
+        metadata = response.get("CurrentURIMetaData")
+        if metadata:
+            metadata = XML.fromstring(really_utf8(metadata))
+            md_title = metadata.findtext(".//{http://purl.org/dc/elements/1.1/}title")
+
+            if md_title:
+                media["channel"] = md_title
+
+        return media
+
     def get_speaker_info(self, refresh=False, timeout=None):
         """Get information about the Sonos speaker.
 
