@@ -708,6 +708,12 @@ class TestAVTransport:
         moco.stop()
         moco.avTransport.Stop.assert_called_once_with([("InstanceID", 0), ("Speed", 1)])
 
+    def test_soco_end_direct_control_session(self, moco):
+        moco.end_direct_control_session()
+        moco.avTransport.EndDirectControlSession.assert_called_once_with(
+            [("InstanceID", 0)]
+        )
+
     def test_soco_next(self, moco):
         moco.next()
         moco.avTransport.Next.assert_called_once_with([("InstanceID", 0), ("Speed", 1)])
@@ -1441,6 +1447,9 @@ class TestZoneGroupTopology:
     def test_soco_is_coordinator(self, moco_zgs):
         assert moco_zgs.is_coordinator
 
+    def test_boot_seqnum(self, moco_zgs):
+        assert moco_zgs.boot_seqnum == 162
+
     def test_all_groups(self, moco_zgs):
         groups = moco_zgs.all_groups
         assert len(groups) == 3
